gql.transport.common.adapters.websockets
========================================

.. currentmodule:: gql.transport.common.adapters.websockets

.. automodule:: gql.transport.common.adapters.websockets
    :member-order: bysource
